/*
 * cdrom.h
 *
 * interface declarations for accessing the cdrom drive
 */

#ifndef CDROM_H
#define CDROM_H

#include <sys/types.h>

#include <linux/cdrom.h>

typedef struct {
  u_char minute;
  u_char second;
  u_char frame;
} cdrom_position_t;

/* This needs to be called ONCE before anything else from in here is
   called. Passing False for enable_mounting will disable mounting. Passing
   NULL for device will result in its  being replaced by hard-coded
   defaults. */ 
/* Returns -1 if error, 0 otherwise */
int init_cdrom(char *device, int enable_mounting);

/* State predicates */
/* These should be self-explanatory. They return 0 if all OK, -1 if
   not (errno set appropriately */

int cdrom_tray_open();
int cdrom_cd_in_drive();
int cdrom_mounted();
int cdrom_playing();
int cdrom_paused();
int cdrom_cd_is_data_only();
int cdrom_cd_is_mixed_mode();
int cdrom_cd_contains_data();

/* This one returns the number of the current track. Note: The current
   track isn't necessarily playing! (E.g. you can skip
   forward/backward without the CD playing). Returns -1 if no tracks
   can be found (i.e. no CD in the drive).*/

int cdrom_current_track();

/* This one sets the current track. Returns 0 if OK, -1 if the track
   number you passed can not be found. Note: The first track is track
   no 1! */

int cdrom_set_current_track(int track);

/* This one tells you if the track given is data (0), audio (1) or not
   on the CD (-1). */

int cdrom_track_type(int track);

/* These return -1 if not currently playing any track, 0
   otherwise, and put the info in position_return */
/* relative to the current track */
int cdrom_get_position_relative(cdrom_position_t *position_return);
/* relative to the start of the CD */
int cdrom_get_position_absolute(cdrom_position_t *position_return);

/* -1 if error, no of tracks on CD otherwise */
int cdrom_no_of_tracks();

int cdrom_get_length_of_track(int track, cdrom_position_t
			      *length_return);

/* -1 if error, 0 otherwise */
int cdrom_length_of_cd(cdrom_position_t *length_return);



/* Actions. All of these return -1 if error, 0 otherwise */

int cdrom_play_absolute(cdrom_position_t pos)
int cdrom_play(); /* Plays the current track, restarting if already
		     playing */
int cdrom_pause(); /* Toggles pause */
int cdrom_stop();
int cdrom_skipf(); /* Skips forward, returning to the first track if
		      skipped beyond the last. Doesn't change
		      playing/paused status */
int cdrom_skipb(); /* analogous */

int cdrom_skipf_audio(); /* Analogous to cdrom_skipf, but
			    automatically skips over any non-audio
			    tracks it finds */
int cdrom_skipb_audio();

/* mount the device using the settings given by cdrom_init(). */
/* Returns -1 if failed, 0 if OK */
int cdrom_mount();
int cdrom_umount();

/* Open/close the tray. Note: Some CDROMS don't support closing the
   tray. For those, cdrom_closetray() will always return -1. */
int cdrom_closetray();
int cdrom_opentray();


/* Returns -1 if error, 0 otherwise */
int cdrom_update_state();

/* This checks the mtab and sets an internal state variable
   accordingly. cdrom_update_state() calls this, so normally you
   shouldn't have to worry. */
void cdrom_check_mounted();


#endif /* CDROM_H */
